summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvastext_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvastext_imp.h')
-rw-r--r--kjsembed/qtbindings/qcanvastext_imp.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kjsembed/qtbindings/qcanvastext_imp.h b/kjsembed/qtbindings/qcanvastext_imp.h
index 11f50a51..e4e40590 100644
--- a/kjsembed/qtbindings/qcanvastext_imp.h
+++ b/kjsembed/qtbindings/qcanvastext_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TQCanvasText;
+class TTQCanvasText;
/**
* Namespace containing the KJSEmbed library.
@@ -17,11 +17,11 @@ class TQCanvasText;
namespace KJSEmbed {
/**
* Wrapper class for TQCanvasText methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QCanvasTextImp : public JSProxyImp
+class TQCanvasTextImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -51,8 +51,8 @@ public:
Method_Last = -1
};
- QCanvasTextImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QCanvasTextImp();
+ TQCanvasTextImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQCanvasTextImp();
/**
* Adds the static bindings for this class to the specified Object. The
@@ -66,15 +66,15 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQCanvasText *toQCanvasText( KJS::Object &object );
+ static TTQCanvasText *toTQCanvasText( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QCanvasText_1( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCanvasText_2( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCanvasText_3( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasText_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasText_2( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasText_3( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -110,7 +110,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQCanvasText *instance; // Temp
+ TTQCanvasText *instance; // Temp
int id;
bool cons;
};
@@ -17,11 +17,11 @@ class TQCanvasText;
namespace KJSEmbed {
/**
- * Wrapper class for TQCanvasText methods.
+ * Wrapper class for TTQCanvasText methods.
*
* @author Richard Moore, rich@kde.org